@@ -1,19 +1,21 @@
 <?php
-define ( "MODULE_ADMIN_HEADLINE", "Permanente Weiterleitungen" );
-define ( "MODULE_ADMIN_REQUIRED_PERMISSION", "redirections301_edit" );
-function redirections301_admin() {
-	if (isset ( $_POST ["submit"] )) {
-		setconfig ( "redirections301", db_escape ( $_POST ["redirections301"] ) );
-	}
-	
-	$redirections301 = getconfig ( "redirections301" );
-	$redirections301 = stringHelper::real_htmlspecialchars ( $redirections301 );
-	?>
+define("MODULE_ADMIN_HEADLINE", "Permanente Weiterleitungen");
+define("MODULE_ADMIN_REQUIRED_PERMISSION", "redirections301_edit");
+
+function redirections301_admin()
+{
+    if (isset($_POST["submit"])) {
+        setconfig("redirections301", db_escape($_POST["redirections301"]));
+    }
+    
+    $redirections301 = getconfig("redirections301");
+    $redirections301 = StringHelper::realHtmlSpecialchars($redirections301);
+    ?>
 
 <form action="<?php echo getModuleAdminSelfPath()?>" method="post">
 <?php
-	csrf_token_html ();
-	?>
+    csrf_token_html();
+    ?>
 <p>
 		Hier können Sie permanente Weiterleitungen (HTTP Status 301)
 		einrichten.<br /> Sie können je einen Eintrag pro Zeile eingeben.
@@ -27,8 +29,8 @@ function redirections301_admin() {
 	<p>
 		<textarea rows="10" cols="80" style="width: 100%"
 			name="redirections301"><?php
-	echo $redirections301;
-	?></textarea>
+    echo $redirections301;
+    ?></textarea>
 	
 	
 	<p>
